==> rsuite-4.1.0.tgz: package/src/Timeline/Timeline.tsx <==
import * as React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import _ from 'lodash';
import setStatic from 'recompose/setStatic';

import TimelineItem from './TimelineItem';
import { defaultProps, prefix, ReactChildren } from '../utils';
import { TimelineProps } from './Timeline.d';
import { TimelineItemProps } from './TimelineItem.d';

class Timeline extends React.Component<TimelineProps> {
  static propTypes = {
    className: PropTypes.string,
    classPrefix: PropTypes.string,
    children: PropTypes.node,
    componentClass: PropTypes.elementType,
    align: PropTypes.oneOf(['left', 'right', 'alternate'])
  };

  static defaultProps = {
    align: 'left'
  };

  render() {
    const {
      children,
      componentClass: Component,
      classPrefix,
      className,
      align,
      ...rest
    } = this.props;
    const addPrefix = prefix(classPrefix);
    const count = React.Children.count(children);
    const withTime = _.some(
      React.Children.toArray<{ props: TimelineItemProps; [key: string]: any }>(children as {
        props: TimelineItemProps;
        [key: string]: any;
      }),
      ({ props }) => !!props.time
    );

    return (
      <Component
        className={classNames(
          classPrefix,
          addPrefix(`align-${align}`),
          {
            [addPrefix('with-time')]: withTime
          },
          className
        )}
        {...rest}
      >
        {ReactChildren.mapCloneElement(children, (_child: any, index: number) => ({
          last: index + 1 === count,
          align
        }))}
      </Component>
    );
  }
}

const EnhancedTimeline = defaultProps<TimelineProps>({
  classPrefix: 'timeline',
  componentClass: 'ul'
})(Timeline);

setStatic('Item', TimelineItem)(EnhancedTimeline);

export default EnhancedTimeline;

==> rsuite-4.1.3.tgz: package/src/Timeline/Timeline.tsx <==
import * as React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import _ from 'lodash';
import setStatic from 'recompose/setStatic';

import TimelineItem from './TimelineItem';
import { defaultProps, prefix, ReactChildren } from '../utils';
import { TimelineProps } from './Timeline.d';
import { TimelineItemProps } from './TimelineItem.d';

class Timeline extends React.Component<TimelineProps> {
  static propTypes = {
    className: PropTypes.string,
    classPrefix: PropTypes.string,
    children: PropTypes.node,
    componentClass: PropTypes.elementType,
    align: PropTypes.oneOf(['left', 'right', 'alternate'])
  };

  static defaultProps = {
    align: 'left'
  };

  render() {
    const {
      children,
      componentClass: Component,
      classPrefix,
      className,
      align,
      ...rest
    } = this.props;
    const addPrefix = prefix(classPrefix);
    const count = React.Children.count(children);
    const withTime = _.some(
      React.Children.toArray<{ props: TimelineItemProps; [key: string]: any }>(
        children as {
          props: TimelineItemProps;
          [key: string]: any;
        }
      ),
      ({ props }) => !!props.time
    );

    return (
      <Component
        className={classNames(
          classPrefix,
          addPrefix(`align-${align}`),
          {
            [addPrefix('with-time')]: withTime
          },
          className
        )}
        {...rest}
      >
        {ReactChildren.mapCloneElement(children, (_child: any, index: number) => ({
          last: index + 1 === count,
          align
        }))}
      </Component>
    );
  }
}

const EnhancedTimeline = defaultProps<TimelineProps>({
  classPrefix: 'timeline',
  componentClass: 'ul'
})(Timeline);

setStatic('Item', TimelineItem)(EnhancedTimeline);

export default EnhancedTimeline;
